#### Online Appendix 5.1 ####

# load packages
  library(lme4)
  library(AICcmodavg)
  library(car)
  library(vegan)

# load data
  ptarmigan=read.csv(file.choose())
  prey=read.csv(file.choose())

# make rarefaction curve by site
  rarecurve (t(prey))

# change some variables to factors
  ptarmigan$nest<-as.factor(ptarmigan$nest)
  ptarmigan$year<-as.factor(ptarmigan$year)

# build generalized linear mixed models
  model1<-glmer(ptar ~ week + year + (1|nest), family = binomial, data = ptarmigan)
  summary(model1)
  model2<-glmer(ptar ~ year + (1|nest), family = binomial, data = ptarmigan)
  model3<-glmer(ptar ~ (1|nest), family = binomial, data = ptarmigan)

# create AIC table
  aictab(cand.set= list(model1, model2, model3), modnames= c('model1','model2','model3'))

# build figure
  p=data.frame(week=unique(ptarmigan$week),year='2014')
  pred=data.frame(predictSE(model1,p),week=p$week)
  plot(p$week,pred$fit,type="n",xlab='Week',ylab='Ptarmigan Probability',ylim=c(0,1))
  lines(p$week,pred$fit)
  polygon(c(p$week,rev(p$week)),c(pred$fit-1.96*pred$se.fit,rev(pred$fit+1.96*pred$se.fit)),col=rgb(0, 0, 0,0.5),border=NA)


